You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2016/04/23 16:55:24 UTC

[3/5] isis git commit: ISIS-1389: extending API for Interaction interface.

ISIS-1389: extending API for Interaction interface.


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/113e4aef
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/113e4aef
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/113e4aef

Branch: refs/heads/ISIS-1291
Commit: 113e4aef0d50fdc97de5f97bfe8e74aa3585ad2d
Parents: 98a0c2f
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Sat Apr 23 12:48:17 2016 +0100
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Sat Apr 23 12:48:17 2016 +0100

----------------------------------------------------------------------
 .../apache/isis/applib/services/iactn/Interaction.java   | 11 +++++++++--
 1 file changed, 9 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/113e4aef/core/applib/src/main/java/org/apache/isis/applib/services/iactn/Interaction.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/services/iactn/Interaction.java b/core/applib/src/main/java/org/apache/isis/applib/services/iactn/Interaction.java
index b9445d0..7b889cd 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/services/iactn/Interaction.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/services/iactn/Interaction.java
@@ -126,11 +126,18 @@ public interface Interaction extends HasTransactionId {
     AbstractDomainEvent<?> popDomainEvent();
 
     /**
      * Returns a graph indicating the domain events in the order that they were
      * {@link #pushDomainEvent(AbstractDomainEvent) pushed}.
+     *
+     * <p>
+     *     Each {@link ExecutionGraph} represents a call stack of domain events (action invocations or property edits),
+     *     that may in turn cause other domain events to be fired (by virtue of the {@link WrapperFactory}).
+     *     The reason that a list is returned is to support bulk command/actions (against multiple targets).  A non-bulk
+     *     action will return a list of just one element.
+     * </p>
      */
     @Programmatic
-    ExecutionGraph getDomainEvents();
+    List<ExecutionGraph> getExecutionGraphs();
 
     /**
      * <b>NOT API</b>: intended to be called only by the framework.
@@ -126,11 +126,18 @@ public interface Interaction extends HasTransactionId {
 
     /**
-     * Returns a graph indicating the domain events in the order that they were
+     * Returns a (list of) graph(es) indicating the domain events in the order that they were
      * {@link #pushDomainEvent(AbstractDomainEvent) pushed}.